.. _fields:

Fields
======

Supported form fields
---------------------

The following form fields were tested:

* ``BooleanField``
* ``CharField``
* ``EmailField``
* ``FloatField``
* ``IntegerField``
* ``URLField``.

Fields that return complex objects are not supported.
Basically any object that can be store in a data base is supported,
except for DateField which is not supported at this time (sorry).


